==> pylucene-2.9.1-1-src.tar.gz: pylucene-2.9.1-1/lucene-java-2.9.1/contrib/queryparser/src/java/org/apache/lucene/queryParser/standard/config/FieldBoostMapFCListener.java <==
package org.apache.lucene.queryParser.standard.config;

/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.lucene.queryParser.core.config.FieldConfig;
import org.apache.lucene.queryParser.core.config.FieldConfigListener;
import org.apache.lucene.queryParser.core.config.QueryConfigHandler;

/**
 * This listener listens for every field configuration request and assign a
 * {@link BoostAttribute} to the equivalent {@link FieldConfig} based on a
 * defined map: fieldName -> boostValue store in {@link FieldBoostMapAttribute}
 * in the {@link FieldBoostMapAttribute}.
 * 
 * @see BoostAttribute
 * @see FieldBoostMapAttribute
 * @see FieldConfig
 * @see FieldConfigListener
 */
public class FieldBoostMapFCListener implements FieldConfigListener {

  private static final long serialVersionUID = -5929802948798314067L;

  private QueryConfigHandler config = null;
  
  public FieldBoostMapFCListener(QueryConfigHandler config) {
    this.config = config;
  }

  public void buildFieldConfig(FieldConfig fieldConfig) {    
    if (this.config.hasAttribute(FieldBoostMapAttribute.class)) {
      FieldBoostMapAttribute fieldBoostMapAttr = (FieldBoostMapAttribute) this.config.getAttribute(FieldBoostMapAttribute.class);
      BoostAttribute boostAttr = (BoostAttribute) fieldConfig.addAttribute(BoostAttribute.class);
      
      Float boost = fieldBoostMapAttr.getFieldBoostMap().get(fieldConfig.getFieldName());

      if (boost != null) {
        boostAttr.setBoost(boost.floatValue());
      }

    }
  }

}

==> pylucene-3.0.3-1-src.tar.gz: pylucene-3.0.3-1/lucene-java-3.0.3/contrib/queryparser/src/java/org/apache/lucene/queryParser/standard/config/FieldBoostMapFCListener.java <==
package org.apache.lucene.queryParser.standard.config;

/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.apache.lucene.queryParser.core.config.FieldConfig;
import org.apache.lucene.queryParser.core.config.FieldConfigListener;
import org.apache.lucene.queryParser.core.config.QueryConfigHandler;

/**
 * This listener listens for every field configuration request and assign a
 * {@link BoostAttribute} to the equivalent {@link FieldConfig} based on a
 * defined map: fieldName -> boostValue store in {@link FieldBoostMapAttribute}
 * in the {@link FieldBoostMapAttribute}.
 * 
 * @see BoostAttribute
 * @see FieldBoostMapAttribute
 * @see FieldConfig
 * @see FieldConfigListener
 */
public class FieldBoostMapFCListener implements FieldConfigListener {

  private static final long serialVersionUID = -5929802948798314067L;

  private QueryConfigHandler config = null;
  
  public FieldBoostMapFCListener(QueryConfigHandler config) {
    this.config = config;
  }

  public void buildFieldConfig(FieldConfig fieldConfig) {    
    if (this.config.hasAttribute(FieldBoostMapAttribute.class)) {
      FieldBoostMapAttribute fieldBoostMapAttr = this.config.getAttribute(FieldBoostMapAttribute.class);
      BoostAttribute boostAttr = fieldConfig.addAttribute(BoostAttribute.class);
      
      Float boost = fieldBoostMapAttr.getFieldBoostMap().get(fieldConfig.getFieldName());

      if (boost != null) {
        boostAttr.setBoost(boost.floatValue());
      }

    }
  }

}
